<?php

namespace Hector\Printshop\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hector\Printshop\Models\Clientes;

class ClientesPolicy
{

    /**
     * Determine if the given user can view the clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function view(UserPolicy $user, Clientes $clientes)
    {
        if ($user->canDo('printshop.clientes.view') && $user->isAdmin()) {
            return true;
        }

        return $clientes->user_id == user_id() && $clientes->user_type == user_type();
    }

    /**
     * Determine if the given user can create a clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('printshop.clientes.create');
    }

    /**
     * Determine if the given user can update the given clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function update(UserPolicy $user, Clientes $clientes)
    {
        if ($user->canDo('printshop.clientes.edit') && $user->isAdmin()) {
            return true;
        }

        return $clientes->user_id == user_id() && $clientes->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Clientes $clientes)
    {
        return $clientes->user_id == user_id() && $clientes->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Clientes $clientes)
    {
        if ($user->canDo('printshop.clientes.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given clientes.
     *
     * @param UserPolicy $user
     * @param Clientes $clientes
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Clientes $clientes)
    {
        if ($user->canDo('printshop.clientes.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
